=========
os-traits
=========

`os-traits` is a library containing standardized trait strings.

Traits are strings that represent a feature of some resource provider.  This
library contains the catalog of constants that have been standardized in the
OpenStack community to refer to a particular hardware, virtualization, storage,
network, or device trait.

Installation Guide
------------------

.. toctree::
   :maxdepth: 2

   install/index

Usage Guide
-----------

.. toctree::
   :maxdepth: 2

   user/index

Contributor Guide
-----------------

.. toctree::
   :maxdepth: 2

   contributor/index

Reference
---------

.. toctree::
   :maxdepth: 2

   reference/index
   reference/traits
